@@ -1,5 +1,5 @@
-from abstract_flask import request,initialize_call_log,get_bp,get_request_data
-from abstract_utilities import get_json_call_response
+from abstract_flask import request,get_bp,get_request_data
+from abstract_utilities import get_json_call_response,initialize_call_log
 from abstract_apis import postRequest
 from abstract_security import get_env_value
 proxy_video_url_bp,logger = get_bp('proxy_video_url_bp')
